@@ -6,7 +6,7 @@ BEGIN {
     use Excel::Template::Base;
     use vars qw ($VERSION @ISA);
 
-    $VERSION  = '0.31';
+    $VERSION  = '0.32';
     @ISA      = qw( Excel::Template::Base );
 }
 
@@ -450,14 +450,26 @@ None, that I know of.
 
 This is production quality software, used in several production web applications.
 
-=head1 AUTHOR
+=head1 MAINTAINERS
 
-    Rob Kinyon (rob.kinyon@gmail.com)
+    Jens Gassmann <jegade@cpan.org>
+    Robert Bohne <rbo@cpan.org>
+    Rob Kinyon <rkinyon@cpan.org>
 
 =head1 CONTRIBUTORS
 
 There is a mailing list at http://groups.google.com/group/ExcelTemplate or exceltemplate@googlegroups.com
 
+=head2 Robert Bohne <rbo@cpan.org>
+
+=over 4
+
+=item * Swichting to Module::Install
+
+=item * Add autofilter to worksheet
+
+=back
+
 =head2 Robert Graff
 
 =over 4
@@ -468,6 +480,14 @@ There is a mailing list at http://groups.google.com/group/ExcelTemplate or excel
 
 =back
 
+=head2 Jens Gassmann
+
+=over 4
+
+=item * Add hide_gridlines to worksheet
+
+=back
+
 =head1 TEST COVERAGE
 
 I use L<Devel::Cover> to test the coverage of my tests. Every release, I intend to improve these numbers.
